IotWidgetElement class
Constructors
-
IotWidgetElement({required String id, String title = "", String icon = "", bool? settable, bool? retained, int numOfParameters = 0, List<
AcceptedParameter> acceptedParameters = const <AcceptedParameter>[]}) -
IotWidgetElement.fromJson(Map<
String, dynamic> json)
Properties
-
acceptedParameters
→ List<
AcceptedParameter> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String
-
final
- id → String
-
final
- numOfParameters → int
-
final
- retained → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settable → bool?
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited